@@ -1,6 +1,6 @@
-# Copyright (C) 2003-2008 by Dr. Dieter Maurer, Illtalstr. 25, D-66571 Bubach, Germany
+# Copyright (C) 2003-2009 by Dr. Dieter Maurer, Illtalstr. 25, D-66571 Bubach, Germany
 # see "LICENSE.txt" for details
-#       $Id: ManagableIndex.py,v 1.3 2009/07/08 12:00:10 dieter Exp $
+#       $Id: ManagableIndex.py,v 1.4 2009/10/16 13:28:38 dieter Exp $
 '''Managable Index abstract base class.'''
 
 import copy
@@ -22,7 +22,6 @@ from DateTime.DateTime import DateTime
 from zope.interface import implements
 
 from Products.OFolder.OFolder import OFolder
-from Products.PluginIndexes.interfaces import IPluggableIndex
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
 from fixPluginIndexes import parseIndexRequest
@@ -30,6 +29,7 @@ from Evaluation import Normalize, Ignore, EvalAndCall
 from ValueProvider import AttributeLookup, ExpressionEvaluator
 from Utils import reverseOrder, _LazyMap, \
      convertToDateTime, convertToDateTimeInteger, convertToDateInteger
+from interfaces import IManagableIndex
 
 _mdict= globals()
 
@@ -118,7 +118,7 @@ class ManagableIndex(OFolder,Normalize, Ignore):
   PrenormalizeTerm= ''
   StopTermPredicate= ''
 
-  implements(IPluggableIndex)
+  implements(IManagableIndex)
 
   def __init__(self, name, extra=None, caller=None):
     self.id= name
@@ -639,10 +639,12 @@ class ManagableIndex(OFolder,Normalize, Ignore):
       { 'name' : AttributeLookup.meta_type,
         'action' : 'addAttributeLookupForm',
         'permission' : ManageManagableIndexes,
+        'instance' : lambda id: self._make_child(id, 'AttributeLookup'),
         },
       { 'name' : ExpressionEvaluator.meta_type,
         'action' : 'addExpressionEvaluatorForm',
         'permission' : ManageManagableIndexes,
+        'instance' : lambda id: self._make_child(id, 'ExpressionEvaluator'),
         },
       )
 
@@ -662,21 +664,33 @@ class ManagableIndex(OFolder,Normalize, Ignore):
       action= 'addValueProvider',
       )
 
-  def addValueProvider(self,id,type, RESPONSE=None):
-    '''add a value provider with *id* of *type*.'''
+  @staticmethod
+  def _make_child(id, type):
     if type not in ('AttributeLookup', 'ExpressionEvaluator'):
       raise ValueError('unknown type')
-    cl= _mdict[type]
+    cl = _mdict[type]
+    vp = cl(); vp.id = id
+    return vp
+
+  def addValueProvider(self,id,type, RESPONSE=None):
+    '''add a value provider with *id* of *type*.'''
     # try to avaid a name conflict
-    eid= id
-    if not id.endswith('_') and hasattr(aq_base(self),id): eid= id + '_'
-    vp= cl(); vp.id= eid
-    if id != eid and type == 'AttributeLookup': vp.Name= id
+    eid = id
+    if not id.endswith('_') and hasattr(aq_base(self),id): eid = id + '_'
+    vp = self._make_child(eid, type)
+    if id != eid and type == 'AttributeLookup': vp.Name = id
     self._setObject(eid, vp)
-    vp= self._getOb(eid)
+    vp = self._getOb(eid)
     if RESPONSE is None: return vp
     RESPONSE.redirect('%s/manage_workspace' % vp.absolute_url())
 
+# stupid Zope 2.12 compatibility
+try:
+  # new Zope 2.12 place
+  from App.class_init import InitializeClass
+except ImportError:
+  # try the old place
+  from Globals import InitializeClass
     
 InitializeClass(ManagableIndex)
 
